package info.frostfs.sdk.examples.ape;

import info.frostfs.sdk.FrostFSClient;
import info.frostfs.sdk.dto.ape.*;
import info.frostfs.sdk.dto.chain.ChainTarget;
import info.frostfs.sdk.dto.container.ContainerId;
import info.frostfs.sdk.enums.RuleMatchType;
import info.frostfs.sdk.enums.RuleStatus;
import info.frostfs.sdk.enums.TargetType;
import info.frostfs.sdk.jdo.parameters.CallContext;
import info.frostfs.sdk.jdo.parameters.ape.PrmApeChainAdd;
import org.apache.commons.lang3.ArrayUtils;

import java.nio.charset.StandardCharsets;

public class ApeAddChain {

    public static void example(FrostFSClient frostFSClient, ContainerId containerId, CallContext callContext) {
        frostFSClient.addChain(generatePrmApeChainAdd(containerId), callContext);
    }

    private static PrmApeChainAdd generatePrmApeChainAdd(ContainerId containerId) {
        var chainTarget = new ChainTarget(containerId.getValue(), TargetType.CONTAINER);
        var resources = new Resources(false, new String[]{"native:object/*"});
        var actions = new Actions(false, new String[]{"*"});
        var rule = new Rule();
        rule.setStatus(RuleStatus.ALLOW);
        rule.setResources(resources);
        rule.setActions(actions);
        rule.setAny(false);
        rule.setConditions(new Condition[]{});


        var chain = new Chain();
        chain.setId(ArrayUtils.toObject("chain-id-test".getBytes(StandardCharsets.UTF_8)));
        chain.setRules(new Rule[]{rule});
        chain.setMatchType(RuleMatchType.DENY_PRIORITY);

        return new PrmApeChainAdd(chain, chainTarget);
    }
}
